MethodNode class

Properties

arguments ↔ List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
length → int
no setter
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<T>(T fn(dynamic)) → List<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int idx) → dynamic

Static Properties

defaultNode ↔ MethodNode
getter/setter pair

Static Methods

parse(String str, Status status) → MethodNode?