Template class abstract

Implementers

Constructors

Template(XmlNode node, [Template? parent])
factory
Template.init(XmlNode node, Template? parent)

Properties

attributes → List<Template>
no setter
children → List<Template>
no setter
hashCode → int
The hash code for this object.
no setterinherited
messageFilter → String?
no setter
name → XmlName?
no setter
node ↔ XmlNode
getter/setter pair
parent ↔ Template?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate(Status status, NodeControl control, [FlowMessage? message]) → Iterable<NodeData>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processChildren(Status status, NodeControl control, FlowMessage message) → Iterable<NodeData>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited