SetArgument class

Inheritance

Constructors

SetArgument({String? ret, dynamic argument})

Properties

args ↔ List<Argument>?
getter/setter pairinherited
argument → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
result → dynamic
no setterinherited
ret ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Status status) → dynamic
override
execute(Status status) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited